#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#  tests/client/application.py
#
#  Redistribution and use in source and binary forms, with or without
#  modification, are permitted provided that the following conditions are
#  met:
#
#  * Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
#  * Redistributions in binary form must reproduce the above
#    copyright notice, this list of conditions and the following disclaimer
#    in the documentation and/or other materials provided with the
#    distribution.
#  * Neither the name of the project nor the names of its
#    contributors may be used to endorse or promote products derived from
#    this software without specific prior written permission.
#
#  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
#  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
#  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
#  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
#  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
#  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
#  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
#  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
#  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
#  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
#  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#

import os
import json
import unittest

from king_phisher import find
from king_phisher import testing
from king_phisher.client import application

class ClientApplicationTests(testing.KingPhisherTestCase):
	def test_client_main_window_initialize(self):
		find.data_path_append('data/client')
		application.KingPhisherClientApplication()

	def test_user_paths(self):
		app = application.KingPhisherClientApplication()
		for user_path in (app.user_data_path, app.user_library_path):
			self.assertIsNotNone(user_path)
			self.assertIsNotEmpty(user_path)
			self.assertTrue(os.path.isdir(user_path))
			self.assertTrue(os.access(user_path, os.R_OK | os.W_OK))
			self.assertEqual(user_path, os.path.abspath(user_path))

	def test_client_template_config(self):
		find.data_path_append('data/client')
		config_h = open(find.data_file('client_config.json'))
		try:
			json.load(config_h)
		except Exception:
			self.fail("failed to parse the client JSON configuration file")
		finally:
			config_h.close()

if __name__ == '__main__':
	unittest.main()
